const filterTableId = "#filterTable";


// region Init Module

function initFiltersModule() {
    initializeDataTable(
        filterTableId,
        [
            {
                title: "Name",
                data: "name"
            },
            {
                title: "Match",
                data: "match"
            },
            {
                title: "Algorithm",
                data: "matching_algorithm",
                render: function(data) {
                    switch (data) {
                        case 1: return "Any Word";
                        case 2: return "All Words";
                        case 3: return "Exact Match";
                        case 4: return "Regular Expression";
                        case 5: return "Fuzzy Match";
                        default:
                            console.error(`unknown matching algorithm '${data}'`);
                            return data;
                    }

                }
            },
            {
                title: "Case-Sensitive",
                data: "is_insensitive",
                className: "text-center",
                render: data => renderBooleanColumn(!data)
            },
            {
                title: "Type",
                data: "is_whitelist",
                render: data => data ? "Only Allow" : "Reject All"
            }
        ]
    )
}


// region Load Data

$(document).on("selectedServerChange", async function() {
    await loadFilterData();
});

$(filterTableId).on("doDataLoad", async function() {
    await loadFilterData();
});

async function loadFilterData() {
    if (!selectedServer) {
        return;
    }

    setTableFilter(filterTableId, "server", selectedServer.id);
    await loadTableData(filterTableId, "/api/filters/", "GET");
}
