const styleTableId = "#styleTable";
const styleModalId = "#styleFormModal";


// region Init Module

function initMessageStylesModule() {
    initializeDataTable(
        styleTableId,
        [
            {
                title: "Name",
                data: "name",
                render: function(data) {
                    const name = sanitise(data);
                    return `<button type="button" class="btn btn-link text-start text-decoration-none edit-modal">${name}</button>`;
                }
            },
            {
                title: "Is Embed",
                data: "is_embed",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Is Hyperlinked",
                data: "is_hyperlinked",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Show Author",
                data: "show_author",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Show Timestamp",
                data: "show_timestamp",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Show Images",
                data: "show_images",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Fetch Images",
                data: "fetch_images",
                className: "text-center",
                render: renderBooleanColumn
            },
            {
                title: "Title Mutator",
                data: "title_mutator"
            },
            {
                title: "Description Mutator",
                data: "description_mutator"
            }
        ]
    );
};


// region Load Data

$(document).on("selectedServerChange", async function() {
    await loadMessageStyleData();
});

$(document).on("doDataLoad", async function() {
    await loadMessageStyleData();
});

async function loadMessageStyleData() {
    if (!selectedServer) {
        return;
    }

    setTableFilter(styleTableId, "server", selectedServer.id);
    await loadTableData(styleTableId, "/api/message-styles/", "GET");
}


// region New/Edit Modal

$(styleTableId).closest(".js-tableBody").siblings(".js-tableFilters").on("click", ".table-new-btn", async function() {
    await openDataModal(styleModalId, -1);
});

$(styleTableId).on("click", ".edit-modal", async function() {
    let id = $(styleTableId).DataTable().row($(this).closest("tr")).data().id;
    await openDataModal(styleModalId, id, `/api/message-styles/${id}/`);
});

$(styleModalId).on("submit", async function(event) {
    event.preventDefault();

    if (!selectedServer) {
        throw new Error("Cannot submit form while no server is selected");
    }

    let data = { server: selectedServer.id };

    $(this).find("[data-field]").each(function() {
        const type = $(this).attr("type");
        const key = $(this).attr("data-field");
        if (!key) {
            return;
        }

        let value;
        if (type === "checkbox") {
            value = $(this).prop("checked");
        }
        else {
            value = $(this).val();
        }

        data[key] = value;
    });

    const formData = objectToFormData(data);
    const id = $(this).data("primary-key");

    if (parseInt(id) !== -1) {
        ajaxRequest(`/api/message-styles/${id}/`, "PATCH", formData)
            .then(response => {
                $(this).modal("hide");
                $(styleTableId).trigger("doDataLoad");
            })
            .catch(error => logError(error))
    }
    else {
        ajaxRequest("/api/message-styles/", "POST", formData)
            .then(response => {
                $(this).modal("hide");
                $(styleTableId).trigger("doDataLoad");
            })
            .catch(error => logError(error));
    }
});


// region Load Mutator Options

$(document).ready(async function() {
    await loadMutatorOptions();
});

async function loadMutatorOptions() {
    let $inputs = $(styleModalId).find('[data-field="title_mutator"], [data-field="description_mutator"]');

    $inputs.val("").change();
    $inputs.prop("disabled", true);

    $inputs.find("option").each(function() {
        if ($(this).val()) {
            $(this).remove();
        }
    });

    const data = await ajaxRequest("/api/message-mutators/?page_size=25", "GET");
    data.results.forEach(mutator => {
        $inputs.append($(
            "<option>",
            {text: mutator.name, value: mutator.id}
        ));
    });

    $inputs.prop("disabled", false);
}
